==> read.gb_1.6.tar.gz: read.gb/R/misc_binding.F.R <==
misc_binding.F <- function(Feat, SQuali, SQualiN){
  Item <- c("/allele=", "/bound_moiety=", "/citation=", "/db_xref=", "/experiment=", "/function=", "/gene=", "/gene_synonym=", "/inference=", "/locus_tag=", "/map=", "/note=", "/old_locus_tag=")
  ItemN <- c("allele", "bound_moiety", "citation", "db_xref", "experiment", "function", "gene", "gene_synonym", "inference", "locus_tag", "map", "note", "old_locus_tag")
  Feat[length(Feat)] <- gsub("\\\",$", "", Feat[length(Feat)])
  misc_binding <- data.frame("Location" = "misc_binding", "Qualifier" = gsub(".*misc_binding +([^.]+)\"*", "\\1", Feat[1], perl = T), stringsAsFactors = F)
  for(i in 2:length(Feat)){
    for(j in 1:length(Item)){
      if(length(grep(Item[j], Feat[i], perl = T)) == 1){
        misc_binding <- rbind(misc_binding, c(ItemN[j],  gsub(".*=([^.]+)\"*", "\\1", Feat[i])))
        if((length(grep("\\\\\"$|\"\\\", $", Feat[i])) == 0 & i != length(Feat)) == T){
          t <- i+1
          while(length(grep("\\\\\"$|\"\\\", $", Feat[t])) == 0){
            misc_binding[dim(misc_binding)[1],2] <- paste(misc_binding[dim(misc_binding)[1],2], gsub("\\s", " ", Feat[t]), sep = " ")
            t <- t+1
          }
          if(length(grep("\\\\\"$|\"\\\", $", Feat[t])) == 1){
            misc_binding[dim(misc_binding)[1],2] <- paste(misc_binding[dim(misc_binding)[1],2], gsub("\\s", " ", Feat[t]), sep = " ")
          }
        }
      }
    }
    for(k in 1:length(SQuali)){
      if(length(grep(SQuali[k], Feat[i], perl = T)) == 1){
        misc_binding <- rbind(misc_binding, c(SQuali[k], SQualiN[k]))
      }
    }
  }
  misc_binding <- apply(misc_binding, 2, function(x){gsub(" {2,}", " ", x, perl = TRUE)})
  misc_binding <- apply(misc_binding, 2, function(x){gsub("\"", "", x, fixed = T)})
  misc_binding <- apply(misc_binding, 2, function(x){gsub("\\", "", x, fixed = T)})
  misc_binding <- apply(misc_binding, 2, function(x){gsub("[^[:alnum:][:space:][]'.,:_<>()-]", "", x, perl = TRUE)})
  return(misc_binding)
}

==> read.gb_2.0.1.tar.gz: read.gb/R/misc_binding.F.R <==
misc_binding.F <- function(Feat, SQuali, SQualiN){
  Item <- c("/allele=", "/bound_moiety=", "/citation=", "/db_xref=", "/experiment=", "/function=", "/gene=", "/gene_synonym=", "/inference=", "/locus_tag=", "/map=", "/note=", "/old_locus_tag=")
  ItemN <- c("allele", "bound_moiety", "citation", "db_xref", "experiment", "function", "gene", "gene_synonym", "inference", "locus_tag", "map", "note", "old_locus_tag")
  Feat[length(Feat)] <- gsub("\\\",$", "", Feat[length(Feat)])
  misc_binding <- data.frame("Location" = "misc_binding", "Qualifier" = gsub(".*misc_binding +([^.]+)\"*", "\\1", Feat[1], perl = T), stringsAsFactors = F)
  for(i in 2:length(Feat)){
    for(j in 1:length(Item)){
      if(length(grep(Item[j], Feat[i], perl = T)) == 1){
        misc_binding <- rbind(misc_binding, c(ItemN[j],  gsub(".*=([^.]+)\"*", "\\1", Feat[i])))
        if((length(grep("\\\\\"$|\"\\\", $|\\d$", Feat[i])) == 0 & i != length(Feat)) == T){
          t <- i+1
          while(length(grep("\\\\\"$|\"\\\", $|\\d$", Feat[t])) == 0 && t <= length(Feat)){
            misc_binding[dim(misc_binding)[1],2] <- paste(misc_binding[dim(misc_binding)[1],2], gsub("\\s", " ", Feat[t]), sep = " ")
            t <- t+1
          }
          if(length(grep("\\\\\"$|\"\\\", $|\\d$", Feat[t])) == 1){
            misc_binding[dim(misc_binding)[1],2] <- paste(misc_binding[dim(misc_binding)[1],2], gsub("\\s", " ", Feat[t]), sep = " ")
          }
        }
      }
    }
    for(k in 1:length(SQuali)){
      if(length(grep(SQuali[k], Feat[i], perl = T)) == 1){
        misc_binding <- rbind(misc_binding, c(SQuali[k], SQualiN[k]))
      }
    }
  }
  misc_binding <- apply(misc_binding, 2, function(x){gsub(" {2,}", " ", x, perl = TRUE)})
  misc_binding <- apply(misc_binding, 2, function(x){gsub("\"", "", x, fixed = T)})
  misc_binding <- apply(misc_binding, 2, function(x){gsub("\\", "", x, fixed = T)})
  misc_binding <- apply(misc_binding, 2, function(x){gsub("[^[:alnum:][:space:][]'.,:_<>()-]", "", x, perl = TRUE)})
  return(misc_binding)
}
